@@ -16,7 +16,8 @@
 # Dev branch marker is: 'X.Y.devN' where N is an integer.
 #
 
-__version__ = '0.4'
+__version__ = '0.6'
 
 from .solver import picard  # noqa
-from ._tools import permute  # noqa
+from ._tools import permute, amari_distance  # noqa
+from .dropin_sklearn import Picard  # noqa
